@@ -6,7 +6,7 @@ from typing import Any, Callable, Optional, TYPE_CHECKING
 from functools import wraps
 
 import rich
-from fsspec_utils import (AbstractFileSystem, BaseStorageOptions,
+from fsspeckit import (AbstractFileSystem, BaseStorageOptions,
                           DirFileSystem, filesystem)
 from loguru import logger
 
@@ -370,8 +370,10 @@ class FlowerPowerProject:
                     f"{settings.CONFIG_DIR}",
                     settings.PIPELINES_DIR,
                     hooks_dir,
-                    "README.md"
+                    recursive=True,
                 )
+                if fs.exists("README.md"):
+                    fs.rm("README.md")
             else:
                 error_msg = f"Project already exists at {base_dir}. Use overwrite=True to overwrite the existing project."
                 rich.print(f"[red]{error_msg}[/red]")
@@ -523,4 +525,4 @@ FlowerPower = create_project
 
 # The standalone init function is removed as it was a direct pass-through
 # to FlowerPowerProject.new(). Users can now use FlowerPowerProject.new() directly
-# or the new create_project() function which handles both loading and initialization.
\ No newline at end of file
+# or the new create_project() function which handles both loading and initialization.
