@@ -1,5 +1,7 @@
 from .manager import PipelineManager
+from .pipeline import Pipeline
 
 __all__ = [
     "PipelineManager",
+    "Pipeline",
 ]
